@@ -16,12 +16,38 @@
 #' @param x0 Integer with the starting age the closing method will be fitted from. Default is the last age fitted by the 'DLM' object.
 #' @param max_age Integer with the maximum age the closing method will be fitted. Default age is '120'.
 #' @param k Integer representing the size of the age-interval to be mixed with the 'linear' or 'gompertz' closing methods for a smooth graduation. If k = 0, no mixing will be made. Default: 7.
-#' @param weights Vector of weights to be applied in the mixing of the life tables. Vector's size should be equal to k.
-#' @param new_data Vector containing the log mortality rates in the period after the x0 input. This argument is necessary in the 'linear' and 'gompertz' closing methods.
+#' @param weights Vector of weights of the closing method used in the mixture of the closing method and the fitted model made in the mixing age group. The vector's size should be equal to 2k+1. For a better understanding of this parameter and the mixture applied in this function, see Details.
+#' @param new_data Vector containing the log mortality rates of ages after the x0 input. This is an optional argument used in the 'linear' and 'Gompertz' closing methods.
+#'
+#' @details
+#' #' There are three types of age groups when the closing method is applied: a group
+#' where only the fitted model (DLM) computes the death probabilities, followed by a
+#' group in which the death probabilities are a mix (or more precise a weighted mean)
+#' from the HP model and the closing method and followed by a group in which the
+#' death probabilities are computed just by the closing method. The mix is applied
+#' so the transition of the death probabilities of the ages between the fitted model
+#' and the closing method occurs smoothly.
+#'
+#' The parameters 'x0' and 'k' define the mixing group age. The parameter 'x0'
+#' indicates the center age of the group. The parameter 'k' is the range of ages
+#' before 'x0' and after 'x0', so this group has a total of \eqn{2k + 1} age. Therefore,
+#' the parameter 'weights' must have a length size equal to \eqn{2k + 1}. In this case,
+#' the death probability is calculated as follows. Consider \eqn{model_x} and \eqn{close_x}
+#' as the death probability of the fitted model and closing method in the age \eqn{x},
+#' respectively. Then, the resulting death probability of the mix is calculated as:
+#'
+#' \eqn{q_x = w_x model_x + (1-w_x)close_x},
+#'
+#' where \eqn{w_x} represents the weight of the closing method in the age \eqn{x}. This
+#' procedure is applied only in the linear and Gompertz methods.
+#'
+#'
+#' The three closing methods implemented by the function are:
 #'
-#' @details The three closing methods implemented by the function are:
 #' 1.'linear' method: Fits a linear regression starting at age x0 - k until the last age with data available
+#'
 #' 2.'gompertz' method: Used as the closing method of the 2010-2012 English Life Table No. 17, fits the Gompertz mortality law via SIR using the same available data as the 'linear' method.
+#'
 #' 3.'plateau' method: Keeps the death probability (qx) constant after the x0 argument.
 #'
 #' @return Returns a `ClosedDLM` class object with the predictive chains of the death probability
@@ -41,7 +67,7 @@
 #' Dx = USA2010$Dx.Male[x+1]
 #' y <- log(Dx/Ex)
 #'
-#' fit <- dlm(y, M = 100, bn = 20, thin = 1)
+#' fit <- dlm(y, M = 100)
 #'
 #' ## Applying the closing function with different methods:
 #' close1 = dlm_close(fit, method = "plateau")
@@ -154,7 +180,7 @@ dlm_close = function(fit, method = c("linear", "gompertz", "plateau"), x0 = max(
   if(method == "plateau"){
 
     #gets the death probability of x0 and applies it till max_age
-    sim <- 1 - exp(-exp(rnorm(num_sim, fit$mu[,x0-min_age+1], sqrt(fit$sig2))))
+    sim <- 1 - exp(-exp(rnorm(num_sim, fit$mu[,x0-min_age+1], 0.01*fit$sig2)))
     closed <- matrix(sim, num_sim, old_len)
     colnames(closed) = old_x
 
@@ -175,7 +201,7 @@ dlm_close = function(fit, method = c("linear", "gompertz", "plateau"), x0 = max(
     RMAT = (diag(old_len) + Cpred)
 
     for (i in 1:num_sim){
-      sig = sqrt(fit$sig2[i])
+      sig = 0.01*fit$sig2[i]
       SIGMApred = sig * RMAT
 
       sim_vals = MASS::mvrnorm(1, mu = pred, Sigma = SIGMApred)
@@ -189,7 +215,7 @@ dlm_close = function(fit, method = c("linear", "gompertz", "plateau"), x0 = max(
 
     for (i in 1:num_sim){
       gomp = param[i,1]*exp(param[i,2]*old_x)
-      sim = 1 - exp(-exp(rnorm(old_len, log(gomp), sqrt(fit$sig2[i]))))
+      sim = 1 - exp(-exp(rnorm(old_len, log(gomp), 0.01*fit$sig2[i])))
       closed[i, ] = sim
     }
   }
@@ -207,7 +233,7 @@ dlm_close = function(fit, method = c("linear", "gompertz", "plateau"), x0 = max(
   ####################################################################################################
   t = ncol(fit$mu)
   for (i in 1:num_sim){
-    sim = rnorm(t, fit$mu[i,], sqrt(fit$sig2[i]))
+    sim = rnorm(t, fit$mu[i,], 0.01*fit$sig2[i])
     fitted[i, (min_age+1):(t+min_age)] = 1 - exp(-exp(sim))
   }
   ####################################################################################################
