@@ -202,23 +202,26 @@ hp_lognormal <- function(x, Ex, Dx, M = 100000, bn = round(M/4), thin = 1, m = N
     aux <- rgamma(1, alpha.s2.post, beta.s2.post)
     sigma2[k] <- 1/aux
 
-
     limite_inf = which(theta.post[k,] <= c(1e-16, 1e-16, 1e-16, 1e-16, 1e-16, 15+1e-16, 1e-16, 1e-16))
     limite_sup = which(theta.post[k,] >= c(1-1e-5, 1-1e-5, 1-1e-5, 1-1e-5, Inf, 110-1e-5, 1-1e-5, Inf))
 
     if(length(limite_inf) > 0){
       theta.post[k, limite_inf] <- theta.post[k-1, limite_inf]
-      param_problemas = append(param_problemas, param[limite_inf]); warn = T
+      if(k > bn){
+        param_problemas = append(param_problemas, param[limite_inf]); warn = T
+      }
     }
 
     if(length(limite_sup) > 0){
       theta.post[k, limite_sup] <- theta.post[k-1, limite_sup]
-      param_problemas = append(param_problemas, param[limite_sup]); warn = T
+      if(k > bn){
+        param_problemas = append(param_problemas, param[limite_sup]); warn = T
+      }
     }
 
   })
 
-  if(warn){ warning(paste0("MCMC had some problem with parameter(s): ", paste(sort(unique(param_problemas)), collapse = ", "), ". Try to assign informative prior distributions.")) }
+  if(warn){ warning(paste0("MCMC may have had some issues with the parameter(s): ", paste(sort(unique(param_problemas)), collapse = ", "), ".\nCheck the 'plot_chain' function output to visualize the parameters chain. It might be helpful to assign informative prior distribution for these parameters. See ?hp.")) }
 
   ##############################################################################################
   ### Return
