@@ -202,18 +202,22 @@ hp_lognormal_red <- function(x, Ex, Dx, M = 100000, bn = round(M/4), thin = 1, m
     limite_sup = which(theta.post[k,4:8] >= c(1-1e-5, Inf, 110-1e-5, 1-1e-5, Inf))
 
     if(length(limite_inf) > 0){
-      theta.post[k, 3 + limite_inf] <- theta.post[k-1, 3 + limite_inf]
-      param_problemas = append(param_problemas, param[3 + limite_inf]); warn = T
+      theta.post[k, limite_inf] <- theta.post[k-1, limite_inf]
+      if(k > bn){
+        param_problemas = append(param_problemas, param[limite_inf]); warn = T
+      }
     }
 
     if(length(limite_sup) > 0){
-      theta.post[k, 3 + limite_sup] <- theta.post[k-1, 3 + limite_sup]
-      param_problemas = append(param_problemas, param[3 + limite_sup]); warn = T
+      theta.post[k, limite_sup] <- theta.post[k-1, limite_sup]
+      if(k > bn){
+        param_problemas = append(param_problemas, param[limite_sup]); warn = T
+      }
     }
 
   })
 
-  if(warn){ warning(paste0("MCMC had some problem with parameter(s): ", paste(sort(unique(param_problemas)), collapse = ", "), ". Try to assign informative prior distributions.")) }
+  if(warn){ warning(paste0("MCMC may have had some issues with the parameter(s): ", paste(sort(unique(param_problemas)), collapse = ", "), ".\nCheck the 'plot_chain' function output to visualize the parameters chain. It might be helpful to assign informative prior distribution for these parameters. See ?hp.")) }
 
   ##############################################################################################
   ### Return
