@@ -24,12 +24,10 @@
 #' Ex = USA2000$Ex.Total[x+1]
 #' Dx = USA2000$Dx.Total[x+1]
 #'
-#' mx_t = Dx/Ex
-#' qx_t = 1 - exp(-mx_t)
-#' y = log(qx_t)
+#' y = log(Dx/Ex)
 #'
 #' ## Fitting dlm
-#' fit = dlm(y, M = 100, bn = 20, thin = 1)
+#' fit = dlm(y, M = 100)
 #'
 #' ## Extrapolating the death probabilities (qx)
 #' predict(fit, h = 3, prob = 0.95)
@@ -50,37 +48,39 @@ predict.DLM <- function(object, h, prob = 0.95, ...){
   y = fit$info$y
   Gt = fit$info$Gt
   Ft = fit$info$Ft
-  delta = fit$info$delta
-  V = fit$sig2
-  n = length(V)
+  delta = fit$info$delta[length(fit$info$delta)]
+  # V = fit$sig2
+  V = 0.01 ## same value used in Filtering
+  sig2 = fit$sig2
+  n = length(fit$sig2)
+
+  aux = fit$param
 
   sim <- matrix(NA_real_, nrow = n, ncol = h)
 
-  for(i in 1:n){
-    aux = ff(m0 = fit$info$prior$m0, C0 = fit$info$prior$C0, y = as.matrix(y),
-             V = V[i], Ft = Ft, Gt = Gt, delta = delta)
+  Wt = aux$Ct[N,,] * (1 - delta) / delta
+  at = Gt %*% aux$mt[N,]
+  Rt = Gt %*% aux$Ct[N,,] %*% t(Gt) + Wt
+  ft = Ft %*% at
+  Qt = (Ft %*% Rt %*% t(Ft) + V)[1,1]
+  At = Rt %*% t(Ft) / Qt
+  Ct = Rt - At %*% Ft %*% Rt   ## second moment
 
-    Wt = aux$C[N,,] * (1 - delta) / delta
-    at = Gt %*% aux$m[N,]
-    Rt = Gt %*% aux$C[N,,] %*% t(Gt) + Wt
+  # sim[, 1] <- rnorm(n, mean = ft, sd = sd(Qt * sig2))
+  sim[, 1] <- rt(n, df = 2*aux$alpha)*sqrt(Qt*(aux$beta/aux$alpha)) + c(ft)
+
+  if(h > 1) for(k in 2:h){
+    Wt = Ct * (1 - delta) / delta
+    at = Gt %*% at
+    Rt = Gt %*% Rt %*% t(Gt) + Wt
     ft = Ft %*% at
-    Qt = Ft %*% Rt %*% t(Ft) + V[i]
-    At = Rt %*% t(Ft) %*% chol2inv(chol(Qt))
+    Qt = (Ft %*% Rt %*% t(Ft) + V)[1,1]
+    At = Rt %*% t(Ft) / Qt
     Ct = Rt - At %*% Ft %*% Rt   ## second moment
 
-    sim[i, 1] <- MASS::mvrnorm(1, ft, Qt)
+    # sim[, k] <- rnorm(n, mean = ft, sd = sd(Qt * sig2))
+    sim[, k] <- rt(n, df = 2*aux$alpha)*sqrt(Qt*(aux$beta/aux$alpha)) + c(ft)
 
-    if(h > 1) for(k in 2:h){
-      Wt = Ct * (1 - delta) / delta
-      at = Gt %*% at
-      Rt = Gt %*% Rt %*% t(Gt) + Wt
-      ft = Ft %*% at
-      Qt = Ft %*% Rt %*% t(Ft) + V[i]
-      At = Rt %*% t(Ft) %*% chol2inv(chol(Qt))
-      Ct = Rt - At %*% Ft %*% Rt   ## second moment
-
-      sim[i, k] <- MASS::mvrnorm(1, ft, Qt)
-    }
   }
 
   qx_sim = exp(sim)
@@ -89,7 +89,7 @@ predict.DLM <- function(object, h, prob = 0.95, ...){
   qx_fitted = apply(qx_sim, 2, median, na.rm = T)
   qx_lim = apply(qx_sim, 2, quantile, probs = c((1-prob)/2, (1+prob)/2), na.rm = T)
   qx_fitted = data.frame(Ages = (fit$info$ages[N]+1):(fit$info$ages[N]+h), qx_fitted = qx_fitted)
-  return(data.frame(Ages = qx_fitted$Ages, qx_fitted = qx_fitted$qx_fitted,
-                    qx_inf = qx_lim[1,], qx_sup = qx_lim[2,]))
+  return(data.frame(age = qx_fitted$Ages, qx.fitted = 1 - exp(-qx_fitted$qx_fitted),
+                    qx.lower = 1 - exp(-qx_lim[1,]), qx.upper = 1 - exp(-qx_lim[2,])))
 }
 
